use clap::{App, Arg};

pub fn parse_config() -> Config {
    let args = App::new("Clipwatch")
        .version(option_env!("CARGO_PKG_VERSION").unwrap())
        .author("JMARyA <jmarya@hydrar.de>")
        .about("Keep an eye on the clipboard")
        .arg(
            Arg::with_name("ignore-first")
                .short("i")
                .long("ignore-first")
                .help("ignores the value stored in the clipboard at the start of the programm")
                .takes_value(false),
        )
        .arg(
            Arg::with_name("summary")
                .short("s")
                .long("summary")
                .help("at termination of the programm all captured content will be copied into the clipboard")
                .takes_value(false),
        )
        .arg(Arg::with_name("quiet").short("q").long("quiet").help("Dont print to stdout").takes_value(false))
        .arg(Arg::with_name("transform").short("t").long("transform").help("Apply a format string to each clipboard content. Any `{}` will be replaced by the content.").takes_value(true).required(false))
        .get_matches();
    return Config::new(args);
}

#[derive(Debug)]
pub struct Config {
    pub ignore_first: bool,
    pub summary: bool,
    pub quiet: bool,
    pub transform: Option<String>,
}

impl Config {
    fn new(args: clap::ArgMatches) -> Config {
        return Config {
            ignore_first: args.is_present("ignore-first"),
            summary: args.is_present("summary"),
            quiet: args.is_present("quiet"),
            transform: args.value_of("transform").map(|x| x.to_owned()),
        };
    }
}
